@@ -4,10 +4,10 @@ from __future__ import unicode_literals
 from distutils import version
 
 
-__version__ = '0.2.0'
+__version__ = '0.2.1'
 version_info = version.StrictVersion(__version__).version
 
 
-from .base import FileMakerModel  # NOQA
-from .exceptions import *  # NOQA
-from . import fields  # NOQA
+from filemaker.base import FileMakerModel  # NOQA
+from filemaker.exceptions import *  # NOQA
+from filemaker import fields  # NOQA
